@@ -1,11 +1,13 @@
 package CryptoTron::Modules;
-use CryptoTron::MyFilterMacro;  # <-- The magic is found here.
-# Lines below will be expanded into caller's code.
+use CryptoTron::FilterMacro;  # <-- The magic is found here.
+# The lines below will be expanded into the caller's code.
+use CryptoTron::BroadcastTransaction;
 use CryptoTron::GetAccount;
 use CryptoTron::GetAccountNet;
 use CryptoTron::GetAccountResource;
+use CryptoTron::GetBrokerage;
 use CryptoTron::GetReward;
-use CryptoTron::BroadcastTransaction;
-use CryptoTron::WithdrawBalance;
 use CryptoTron::ParseAccount;
-#1;
+use CryptoTron::WithdrawBalance;
+# Package terminator 1; will not be written to caller's code.
+1;
